package com.bonus.canteen.core.menu.service;

import java.util.List;
import com.bonus.canteen.core.menu.domain.MenuEvaluaPicture;

/**
 * 订单评价菜品Service接口
 * 
 * @author xsheng
 * @date 2025-04-20
 */
public interface IMenuEvaluaPictureService {
    /**
     * 查询订单评价菜品
     * 
     * @param id 订单评价菜品主键
     * @return 订单评价菜品
     */
    public MenuEvaluaPicture selectMenuEvaluaPictureById(Long id);

    /**
     * 查询订单评价菜品列表
     * 
     * @param menuEvaluaPicture 订单评价菜品
     * @return 订单评价菜品集合
     */
    public List<MenuEvaluaPicture> selectMenuEvaluaPictureList(MenuEvaluaPicture menuEvaluaPicture);

    /**
     * 新增订单评价菜品
     * 
     * @param menuEvaluaPicture 订单评价菜品
     * @return 结果
     */
    public int insertMenuEvaluaPicture(MenuEvaluaPicture menuEvaluaPicture);

    /**
     * 修改订单评价菜品
     * 
     * @param menuEvaluaPicture 订单评价菜品
     * @return 结果
     */
    public int updateMenuEvaluaPicture(MenuEvaluaPicture menuEvaluaPicture);

    /**
     * 批量删除订单评价菜品
     * 
     * @param ids 需要删除的订单评价菜品主键集合
     * @return 结果
     */
    public int deleteMenuEvaluaPictureByIds(Long[] ids);

    /**
     * 删除订单评价菜品信息
     * 
     * @param id 订单评价菜品主键
     * @return 结果
     */
    public int deleteMenuEvaluaPictureById(Long id);
}
