package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.menu.domain.MenuEvaluaPicture;
import com.bonus.canteen.core.menu.service.IMenuEvaluaPictureService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 订单评价菜品Controller
 * 
 * @author xsheng
 * @date 2025-04-20
 */
@Api(tags = "订单评价菜品接口")
@RestController
@RequestMapping("/menu_evalua_picture")
public class MenuEvaluaPictureController extends BaseController {
    @Autowired
    private IMenuEvaluaPictureService menuEvaluaPictureService;

    /**
     * 查询订单评价菜品列表
     */
    @ApiOperation(value = "查询订单评价菜品列表")
    //@RequiresPermissions("menu:picture:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuEvaluaPicture menuEvaluaPicture) {
        startPage();
        List<MenuEvaluaPicture> list = menuEvaluaPictureService.selectMenuEvaluaPictureList(menuEvaluaPicture);
        return getDataTable(list);
    }

    /**
     * 导出订单评价菜品列表
     */
    @ApiOperation(value = "导出订单评价菜品列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:picture:export")
    @SysLog(title = "订单评价菜品", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出订单评价菜品")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuEvaluaPicture menuEvaluaPicture) {
        List<MenuEvaluaPicture> list = menuEvaluaPictureService.selectMenuEvaluaPictureList(menuEvaluaPicture);
        ExcelUtil<MenuEvaluaPicture> util = new ExcelUtil<MenuEvaluaPicture>(MenuEvaluaPicture.class);
        util.exportExcel(response, list, "订单评价菜品数据");
    }

    /**
     * 获取订单评价菜品详细信息
     */
    @ApiOperation(value = "获取订单评价菜品详细信息")
    //@RequiresPermissions("menu:picture:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuEvaluaPictureService.selectMenuEvaluaPictureById(id));
    }

    /**
     * 新增订单评价菜品
     */
    @ApiOperation(value = "新增订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:picture:add")
    @SysLog(title = "订单评价菜品", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增订单评价菜品")
    @PostMapping
    public AjaxResult add(@RequestBody MenuEvaluaPicture menuEvaluaPicture) {
        try {
            return toAjax(menuEvaluaPictureService.insertMenuEvaluaPicture(menuEvaluaPicture));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改订单评价菜品
     */
    @ApiOperation(value = "修改订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:picture:edit")
    @SysLog(title = "订单评价菜品", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改订单评价菜品")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuEvaluaPicture menuEvaluaPicture) {
        try {
            return toAjax(menuEvaluaPictureService.updateMenuEvaluaPicture(menuEvaluaPicture));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除订单评价菜品
     */
    @ApiOperation(value = "删除订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:picture:remove")
    @SysLog(title = "订单评价菜品", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除订单评价菜品")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuEvaluaPictureService.deleteMenuEvaluaPictureByIds(ids));
    }
}
